(forward-char)
(forward-char)
(delete-char 1)
(save-buffer)
(save-buffers-kill-emacs)
